@@ -1,4 +1,4 @@
-// Heatbugs application. Copyright (C) 1996-1999 Santa Fe Institute.
+// Heatbugs application. Copyright  1996-1999 Santa Fe Institute.
 // This library is distributed without any warranty; without even the
 // implied warranty of merchantability or fitness for a particular purpose.
 // See file LICENSE for details and terms of copying.
@@ -65,11 +65,9 @@ const HeatValue maxHeat = 0x7fff;
 {
   HeatValue bestHeat;
   int x, y;
-  int bestX, bestY;
   id <List>heatList;
   id  cell, bestCell;
   int offset;
-  char buf[100];
 
   // prime loop: assume extreme is right where we're standing
   bestHeat = [self getValueAtX: *px Y: *py];
