@@ -1,4 +1,4 @@
-// Swarm library. Copyright (C) 1996-1999 Santa Fe Institute.
+// Swarm library. Copyright  1996-1999 Santa Fe Institute.
 // This library is distributed without any warranty; without even the
 // implied warranty of merchantability or fitness for a particular purpose.
 // See file LICENSE for details and terms of copying.
@@ -8,19 +8,21 @@
 
 @implementation DiscreteToroid
 
--getObjectAtX: (int) inX Y: (int) inY {
+- getObjectAtX: (unsigned)inX Y: (unsigned)inY
+{
   inX = [self wrapXCoord: inX];
   inY = [self wrapYCoord: inY];
   return [super getObjectAtX: inX Y: inY];
 }
 
--putObject: (id) anObject atX: (int) inX Y: (int) inY {
+- putObject: anObject atX: (unsigned)inX Y: (unsigned)inY
+{
   inX = [self wrapXCoord: inX];
   inY = [self wrapYCoord: inY];
   return [super putObject: anObject atX: inX Y: inY];
 }
 
--(int) wrapCoord: (int) inCoord atModulus: (int) inModulus
+-(int)wrapCoord: (int)inCoord atModulus: (int)inModulus
 {
   /* I have just tried and failed to find out
      definitively whether the behaviour of the %
@@ -35,12 +37,12 @@
   return (inCoord % inModulus);
 }
 
--(int) wrapXCoord: (int) inCoord
+- (int)wrapXCoord: (int)inCoord
 {
   return [self wrapCoord: inCoord atModulus: xsize];
 }
 
--(int) wrapYCoord: (int) inCoord
+- (int)wrapYCoord: (int)inCoord
 {
   return [self wrapCoord: inCoord atModulus: ysize];
 }
