@@ -1,4 +1,4 @@
-// Mousetraps application. Copyright (C) 1996-1999 Santa Fe Institute.
+// Mousetraps application. Copyright  1996-1999 Santa Fe Institute.
 // This library is distributed without any warranty; without even the
 // implied warranty of merchantability or fitness for a particular purpose.
 // See file LICENSE for details and terms of copying.
@@ -110,7 +110,7 @@
 + createBegin: aZone
 {
   MousetrapModelSwarm * obj;
-  id <ProbeMap> probeMap;
+  id <CustomProbeMap> probeMap;
   
   // First, call our superclass createBegin - the return value is the
   // allocated MousetrapModelSwarm object.
@@ -126,28 +126,17 @@
   obj->maxTriggerTime = 16;
   obj->trapDensity = 1.0;
 
-  // And build a customized probe map. Without a probe map, the default
-  // is to show all variables and messages. Here we choose to
+  // And build a customized probe map. Without a probe map, the
+  // default is to show all variables and messages. Here we choose to
   // customize the appearance of the probe, give a nicer interface.
+  // Use the convenience method to create the CustomProbeMap by
+  // specifiying the simulation parameter list
 
-  probeMap = [EmptyProbeMap createBegin: aZone];
-  [probeMap setProbedClass: [self class]];
-  probeMap = [probeMap createEnd];
-
-  // Add in a bunch of variables, one per simulation parameter
-
-  [probeMap addProbe: [probeLibrary getProbeForVariable: "gridSize"
-				    inClass: [self class]]];
-  [probeMap addProbe: [probeLibrary getProbeForVariable: "triggerLikelihood"
-				    inClass: [self class]]];
-  [probeMap addProbe: [probeLibrary getProbeForVariable: "numberOutputTriggers"
-				    inClass: [self class]]];
-  [probeMap addProbe: [probeLibrary getProbeForVariable: "maxTriggerDistance"
-				    inClass: [self class]]];
-  [probeMap addProbe: [probeLibrary getProbeForVariable: "maxTriggerTime"
-				    inClass: [self class]]];
-  [probeMap addProbe: [probeLibrary getProbeForVariable: "trapDensity"
-				    inClass: [self class]]];
+  probeMap = [CustomProbeMap create: aZone
+                             forClass: [self class]
+                             withIdentifiers: "gridSize", "triggerLikelihood",
+                             "numberOutputTriggers", "maxTriggerDistance",
+                             "maxTriggerTime", "trapDensity", ":", NULL];
 
   // Now install our custom probeMap into the probeLibrary.
   
@@ -194,9 +183,7 @@
   
   // Now set up the grid used to represent agent position
   
-  grid = [Grid2d createBegin: [self getZone]];
-  [grid setSizeX: gridSize Y: gridSize];
-  grid = [grid createEnd];
+  grid = [Grid2d create: self setSizeX: gridSize Y: gridSize];
   
   // Then create the mousetraps themselves. We create a mousetrap for
   // each point in the Grid2d, initialize it, and anchor it down
@@ -244,10 +231,8 @@
   
   // just make one schedule. Autodrop, so old activities get destroyed.
   
-  modelSchedule = [Schedule createBegin: [self getZone]];
-  [modelSchedule setAutoDrop: YES];
-  modelSchedule = [modelSchedule createEnd];
-
+  modelSchedule = [Schedule create: self setAutoDrop: YES];
+                            
   // Now, we add one action to the schedule: trigger the mousetrap
   // at the center of the grid. And we also bump up the count of
   // "balls in the air" for bookeeping (This is the ball we will
@@ -302,8 +287,7 @@
   //   See the comments for the ActivityControl attached to the observer
   // swarm in MousetrapObserverSwarm.m
   //
-  modelActCont = [ActivityControl createBegin: [self getZone]];
-  modelActCont = [modelActCont createEnd];
+  modelActCont = [ActivityControl create: self];
   [modelActCont setDisplayName: "Model Swarm Controller"];
   // attach the AC
   [modelActCont attachToActivity: [self getSwarmActivity]];
