@@ -1,7 +1,6 @@
 // simpleBug - tutorial application
 
-
-#import <simtools.h>                // ... for initSwarm() 
+#import <simtools.h>                // ... for initSwarmBatch () 
 #import <activity.h>
 #import "ModelSwarm.h"
 
@@ -12,15 +11,21 @@
 int
 main (int argc, const char **argv)
 {
-  ModelSwarm * modelSwarm;
+  ModelSwarm *modelSwarm;
 
   // Swarm initialization: all Swarm apps must call this first.
 
-  initSwarm(argc, argv);
+  initSwarmBatch (argc, argv);
 
-  // Make the bug model swarm
-
-  modelSwarm =  [ModelSwarm create: globalZone];
+  // Make the bug model swarm, creating the object from the default
+  // `lispAppArchiver' instance which looks for the `bug.scm'
+  // datafile, so we don't have to recompile everytime we want to
+  // change something
+  
+  if ((modelSwarm = 
+       [lispAppArchiver getWithZone: globalZone object: "modelSwarm"]) == nil)
+    raiseEvent(InvalidOperation,
+               "Can't find the modelSwarm parameters");
 
   // Now send messages to the newly created swarm telling it
   // to build its internal objects and its schedule.
@@ -39,5 +44,3 @@ main (int argc, const char **argv)
   return 0;
 
 }
-
-
